@@ -31,3 +31,20 @@ forceAssignInNamespace <- function( x, value, env ){
         lockBinding( x, env )
     }
 }
+
+# Transform a path for passing to the build system on the command line.
+# Leave paths alone for posix. For Windows, mirror the behavior of the 
+# R package build system by starting with the fully resolved absolute path,
+# transforming it to a short path name if it contains spaces, and then 
+# converting backslashes to forward slashes
+asBuildPath <- function(path) {
+    
+    if (.Platform$OS.type == "windows") {
+        path <- normalizePath(path)
+        if (grepl(' ', path, fixed=TRUE))
+            path <- utils::shortPathName(path)
+        path <- gsub("\\\\", "/", path)
+    }
+    
+    return(path)
+}
